@@ -48,8 +48,8 @@ def sign_required(get_secret_by_uaid, ttl):
     return middleware
 
 
-def jwt_token_required(jwt_secret):
-    def get_token_info(authorization : str = Header(...)):
+def get_jwt_info(jwt_secret, invalid_token_error = E.INVALID_TOKEN):
+    def f(authorization : str = Header(...)):
         token = None
         info  = None
 
@@ -64,16 +64,25 @@ def jwt_token_required(jwt_secret):
                 pass
 
         if info is None:
-            raise UniversalLogicError(E.INVALID_TOKEN)
+            raise UniversalLogicError(invalid_token_error)
 
         return info
 
-    return get_token_info
+    return f
 
 
-def auth_required(jwt_secret):
-    async def validate_admin_id(info = Depends(jwt_token_required(jwt_secret))):
-        if "admin_id" not in info:
-            raise UniversalLogicError(E.INVALID_TOKEN)
+def get_jwt_field(field, jwt_secret, invalid_token_error = E.INVALID_TOKEN, field_not_exist_error = E.INVALID_TOKEN):
+    def f(info = Depends(get_jwt_info(jwt_secret, invalid_token_error))):
+        if field not in info:
+            raise UniversalLogicError(field_not_exist_error)
 
-    return adimap(validate_admin_id)
+        return info[field]
+
+    return f
+
+
+def jwt_field_required(field, jwt_secret, invalid_token_error = E.INVALID_TOKEN, field_not_exist_error = E.INVALID_TOKEN):
+    async def f(field_value = Depends(get_jwt_field(field, jwt_secret, invalid_token_error, field_not_exist_error))):
+        pass
+
+    return adimap(f)
